Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1600)

Unified Diff: chrome/browser/chromeos/drive/file_system/get_file_for_saving_operation.h

Issue 23694012: drive: Stop using resource ID to access local metadata in GetFileForSavingOpreation (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/chromeos/drive/file_system/get_file_for_saving_operation.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/chromeos/drive/file_system/get_file_for_saving_operation.h
diff --git a/chrome/browser/chromeos/drive/file_system/get_file_for_saving_operation.h b/chrome/browser/chromeos/drive/file_system/get_file_for_saving_operation.h
index 1bcefa7ee067cf1bebaa48578bb31159eb255874..a9b43cdbd36e81c0cd1980df294df71d38712253 100644
--- a/chrome/browser/chromeos/drive/file_system/get_file_for_saving_operation.h
+++ b/chrome/browser/chromeos/drive/file_system/get_file_for_saving_operation.h
@@ -69,20 +69,22 @@ class GetFileForSavingOperation {
scoped_ptr<ResourceEntry> entry);
void GetFileForSavingAfterMarkDirty(const GetFileCallback& callback,
const base::FilePath& cache_path,
+ const std::string* local_id,
scoped_ptr<ResourceEntry> entry,
FileError error);
void GetFileForSavingAfterWatch(const GetFileCallback& callback,
const base::FilePath& cache_path,
scoped_ptr<ResourceEntry> entry,
bool success);
- // Called when the cache file for |resource_id| is written.
- void OnWriteEvent(const std::string& resource_id);
+ // Called when the cache file for |local_id| is written.
+ void OnWriteEvent(const std::string& local_id);
scoped_ptr<CreateFileOperation> create_file_operation_;
scoped_ptr<DownloadOperation> download_operation_;
scoped_ptr<internal::FileWriteWatcher> file_write_watcher_;
scoped_refptr<base::SequencedTaskRunner> blocking_task_runner_;
OperationObserver* observer_;
+ internal::ResourceMetadata* metadata_;
internal::FileCache* cache_;
// Note: This should remain the last member so it'll be destroyed and
« no previous file with comments | « no previous file | chrome/browser/chromeos/drive/file_system/get_file_for_saving_operation.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698